#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.6
visibility:           public
id:                   tls-session-manager-0.0.6-BibXh7igkPGKS4M0YQzdCS
key:                  tls-session-manager-0.0.6-BibXh7igkPGKS4M0YQzdCS
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  cd16e3ab780ea4c92c1f5a45f40eb360
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.6-BibXh7igkPGKS4M0YQzdCS
depends:
    auto-update-0.1.6-9ZLoXqLZYQc6XJHVsuhZwh base-4.18.2.1
    basement-0.0.16-HvTgG10TboKKpCgs2TlMDx bytestring-0.11.5.3
    clock-0.8.4-KVaAxYiBG7fJzRmSi3lEWo
    crypto-token-0.1.2-7EQrnYhUmm27GPpv7B2AQH
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    psqueues-0.2.8.3-EeA3RtqwMrxBEodzsDu31
    serialise-0.2.6.1-FKJHqJ74sBMG1FsrdXH8EC
    tls-2.0.6-9ENg9yRVcD8IszsfKO7Q8r

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

